@@ -27,6 +27,10 @@
 
 #pragma once
 
+#ifdef WIN32
+#include <winsock2.h>	// needed since libraw 0.16
+#endif
+
 #include <QDialog>
 #include <QLabel>
 #include <QRadioButton>
@@ -46,6 +50,7 @@
 #include <QItemEditorFactory>
 #include <QHeaderView>
 #include <QTreeView>
+#include <QMimeData>
 
 #include <QPrintPreviewWidget>
 #include <QPageSetupDialog>
@@ -54,8 +59,8 @@
 #include <QFormLayout>
 #include <QProgressBar>
 #include <QFuture>
-#include <QtConcurrentRun>
 #include <QFutureWatcher>
+#include <QtConcurrentRun>
 
 #include "DkWidgets.h"
 #include "DkViewPort.h"
@@ -66,25 +71,25 @@ namespace nmc {
 // needed because of http://stackoverflow.com/questions/1891744/pyqt4-qspinbox-selectall-not-working-as-expected 
 // and http://qt-project.org/forums/viewthread/8590
 class DkSelectAllLineEdit : public QLineEdit {
-	public:
-		DkSelectAllLineEdit(QWidget* parent = 0) : QLineEdit(parent) {selectOnMousePressEvent = false;};
+public:
+	DkSelectAllLineEdit(QWidget* parent = 0) : QLineEdit(parent) {selectOnMousePressEvent = false;};
 
-	protected:
-		void focusInEvent(QFocusEvent *event) {
-			QLineEdit::focusInEvent(event);
+protected:
+	void focusInEvent(QFocusEvent *event) {
+		QLineEdit::focusInEvent(event);
+		selectAll();
+		selectOnMousePressEvent = true;
+	}
+
+	void mousePressEvent(QMouseEvent *event) {
+		QLineEdit::mousePressEvent(event);
+		if (selectOnMousePressEvent) {
 			selectAll();
-			selectOnMousePressEvent = true;
+			selectOnMousePressEvent = false;
 		}
-
-		void mousePressEvent(QMouseEvent *event) {
-			QLineEdit::mousePressEvent(event);
-			if (selectOnMousePressEvent) {
-				selectAll();
-				selectOnMousePressEvent = false;
-			}
-		}
-	private:
-		bool selectOnMousePressEvent; 
+	}
+private:
+	bool selectOnMousePressEvent; 
 };
 
 class DkMessageBox : public QDialog {
@@ -131,7 +136,7 @@ class DkSplashScreen : public QDialog {
 	Q_OBJECT
 
 public:
-	DkSplashScreen(QWidget* parent = 0, Qt::WFlags flags = 0);
+	DkSplashScreen(QWidget* parent = 0, Qt::WindowFlags flags = 0);
 	~DkSplashScreen() {};
 
 	//protected:
@@ -249,8 +254,12 @@ public:
 public slots:
 	void on_addButton_clicked();
 	void on_deleteButton_clicked();
+	void on_runButton_clicked();
 	virtual void accept();
 
+signals:
+	void openWithSignal(QAction* act);
+
 protected:
 	DkAppManager* manager;
 	QStandardItemModel* model;
