@@ -30,18 +30,18 @@
 #pragma once
 
 // Qt
-#include <QtGui/QMainWindow>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QShortcut>
-#include <QtGui/QResizeEvent>
-#include <QtGui/QAction>
-#include <QtGui/QFileDialog>
-#include <QtGui/QMessageBox>
-#include <QtGui/QToolBar>
-#include <QtGui/QStatusBar>
-#include <QtGui/QPanGesture>
-#include <QtGui/QSplashScreen>
-#include <QtGui/QErrorMessage>
+#include <QMainWindow>
+#include <QBoxLayout>
+#include <QShortcut>
+#include <QResizeEvent>
+#include <QAction>
+#include <QFileDialog>
+#include <QMessageBox>
+#include <QToolBar>
+#include <QStatusBar>
+#include <QPanGesture>
+#include <QSplashScreen>
+#include <QErrorMessage>
 #include <QDesktopServices>
 #include <QClipboard>
 #include <QEvent>
@@ -52,11 +52,12 @@
 #include <QStringBuilder>
 #include <QDesktopWidget>
 #include <QProgressDialog>
+#include <QDrag>
 
 // OpenCV
 #ifdef WITH_OPENCV
 
-#ifdef Q_WS_WIN
+#ifdef WIN32
 	#pragma warning(disable: 4996)
 #endif
 
@@ -175,6 +176,8 @@ enum {
 	shortcut_delete_silent	= Qt::SHIFT + Qt::Key_Delete,
 	shortcut_crop			= Qt::Key_C,
 	shortcut_copy_buffer	= Qt::CTRL + Qt::SHIFT + Qt::Key_C,
+	shortcut_auto_adjust	= Qt::CTRL + Qt::SHIFT + Qt::Key_L,
+	shortcut_norm_image		= Qt::CTRL + Qt::SHIFT + Qt::Key_N,
 
 	// tcp
 	shortcut_shortcuts		= Qt::CTRL + Qt::Key_K,
@@ -201,9 +204,11 @@ enum fileActions {
 	menu_file_app_manager,
 	menu_file_save,
 	menu_file_save_as,
+	menu_file_save_web,
 	menu_file_rename,
 	menu_file_goto,
 	menu_file_find,
+	menu_file_recursive,
 	menu_file_print,
 	menu_file_reload,
 	menu_file_next,
@@ -240,6 +245,11 @@ enum editActions {
 	menu_edit_transform,
 	menu_edit_delete,
 	menu_edit_crop,
+	menu_edit_flip_h,
+	menu_edit_flip_v,
+	menu_edit_invert,
+	menu_edit_norm,
+	menu_edit_auto_adjust,
 	menu_edit_wallpaper,
 
 	menu_edit_end,	// nothing beyond this point
@@ -456,6 +466,7 @@ public slots:
 	void updateFilterState(QStringList filters);
 	void saveFile();
 	void saveFileAs(bool silent = false);
+	void saveFileWeb();
 	void trainFormat();
 	void resizeImage();
 	void openImgManipulationDialog();
@@ -497,6 +508,11 @@ public slots:
 	void copyImage();
 	void copyImageBuffer();
 	void pasteImage();
+	void flipImageHorizontal();
+	void flipImageVertical();
+	void normalizeImage();
+	void autoAdjustImage();
+	void invertImage();
 	virtual void settingsChanged();
 	void showUpdaterMessage(QString msg, QString title);
 	void showUpdateDialog(QString msg, QString title);
@@ -507,6 +523,7 @@ public slots:
 	void checkForUpdate();
 	void setFrameless(bool frameless);
 	void fitFrame();
+	void setRecursiveScan(bool recursive);
 	void setContrast(bool contrast);
 	void enableMovieActions(bool enable);
 	void clearFileHistory();
@@ -630,7 +647,7 @@ protected:
 	QProcess process;
 
 	// functions
-	DkNoMacs(QWidget *parent = 0, Qt::WFlags flags = 0);
+	DkNoMacs(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 
 	virtual void init();
 	
@@ -652,7 +669,7 @@ class DllExport DkNoMacsSync : public DkNoMacs {
 	Q_OBJECT
 
 public:
-	DkNoMacsSync(QWidget *parent = 0, Qt::WFlags flags = 0);
+	DkNoMacsSync(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 	~DkNoMacsSync();
 	qint16 getServerPort();
 	void syncWith(qint16 port);
@@ -689,7 +706,7 @@ class DllExport DkNoMacsIpl : public DkNoMacsSync {
 	Q_OBJECT
 
 public:
-	DkNoMacsIpl(QWidget *parent = 0, Qt::WFlags flags = 0);
+	DkNoMacsIpl(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 
 };
 
@@ -699,7 +716,7 @@ class DllExport DkNoMacsFrameless : public DkNoMacs {
 	Q_OBJECT
 
 public:
-	DkNoMacsFrameless(QWidget *parent = 0, Qt::WFlags flags = 0);
+	DkNoMacsFrameless(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 	
 	virtual ~DkNoMacsFrameless();
 
@@ -721,7 +738,7 @@ class DllExport DkNoMacsContrast : public DkNoMacsSync {
 	Q_OBJECT
 
 public:
-	DkNoMacsContrast(QWidget *parent = 0, Qt::WFlags flags = 0);
+	DkNoMacsContrast(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 	
 	virtual ~DkNoMacsContrast();
 	void release();	
