@@ -161,7 +161,7 @@ void DkSettings::load(bool force) {
 	global_p.numFiles = settings.value("numFiles", global_p.numFiles).toInt();
 
 	global_p.loop = settings.value("loop", global_p.loop).toBool();
-	global_p.scanSubFolders = settings.value("scanSubFolders", global_p.scanSubFolders).toBool();
+	global_p.scanSubFolders = settings.value("scanRecursive", global_p.scanSubFolders).toBool();
 	global_p.lastDir = settings.value("lastDir", global_p.lastDir).toString();
 	global_p.searchHistory = settings.value("searchHistory", global_p.searchHistory).toStringList();
 	global_p.recentFolders = settings.value("recentFolders", global_p.recentFolders).toStringList();
@@ -180,7 +180,7 @@ void DkSettings::load(bool force) {
 	// Display Settings --------------------------------------------------------------------
 	settings.beginGroup("DisplaySettings");
 
-	display_p.keepZoom = settings.value("resetMatrix", display_p.keepZoom).toBool();
+	display_p.keepZoom = settings.value("keepZoom", display_p.keepZoom).toInt();
 	display_p.invertZoom = settings.value("invertZoom", display_p.invertZoom).toBool();
 	display_p.highlightColor = settings.value("highlightColor", display_p.highlightColor).value<QColor>();
 	display_p.bgColorWidget = settings.value("bgColor", display_p.bgColorWidget).value<QColor>();
@@ -245,6 +245,7 @@ void DkSettings::load(bool force) {
 	resources_p.cacheMemory = settings.value("cacheMemory", resources_p.cacheMemory).toFloat();
 	resources_p.fastThumbnailPreview = settings.value("fastThumbnailPreview", resources_p.fastThumbnailPreview).toBool();
 	resources_p.filterRawImages = settings.value("filterRawImages", resources_p.filterRawImages).toBool();	
+	resources_p.loadRawThumb = settings.value("loadRawThumb", resources_p.loadRawThumb).toInt();	
 	resources_p.filterDuplicats = settings.value("filterDuplicates", resources_p.filterDuplicats).toBool();
 	resources_p.preferredExtension = settings.value("preferredExtension", resources_p.preferredExtension).toString();	
 
@@ -322,7 +323,7 @@ void DkSettings::save(bool force) {
 	if (!force && global_p.loop != global_d.loop)
 		settings.setValue("loop",global_p.loop);
 	if (!force && global_p.scanSubFolders != global_d.scanSubFolders)
-		settings.setValue("scanSubFolders",global_p.scanSubFolders);
+		settings.setValue("scanRecursive",global_p.scanSubFolders);
 	if (!force && global_p.lastDir != global_d.lastDir)
 		settings.setValue("lastDir", global_p.lastDir);
 	if (!force && global_p.searchHistory != global_d.searchHistory)
@@ -353,7 +354,7 @@ void DkSettings::save(bool force) {
 	settings.beginGroup("DisplaySettings");
 
 	if (!force && display_p.keepZoom != display_d.keepZoom)
-		settings.setValue("resetMatrix",display_p.keepZoom);
+		settings.setValue("keepZoom",display_p.keepZoom);
 	if (!force && display_p.invertZoom != display_d.invertZoom)
 		settings.setValue("invertZoom",display_p.invertZoom);
 	if (!force && display_p.highlightColor != display_d.highlightColor)
@@ -448,6 +449,8 @@ void DkSettings::save(bool force) {
 		settings.setValue("fastThumbnailPreview", resources_p.fastThumbnailPreview);
 	if (!force && resources_p.filterRawImages != resources_d.filterRawImages)
 		settings.setValue("filterRawImages", resources_p.filterRawImages);
+	if (!force && resources_p.loadRawThumb != resources_d.loadRawThumb)
+		settings.setValue("loadRawThumb", resources_p.loadRawThumb);
 	if (!force && resources_p.filterDuplicats != resources_d.filterDuplicats)
 		settings.setValue("filterDuplicates", resources_p.filterDuplicats);
 	if (!force && resources_p.preferredExtension != resources_d.preferredExtension)
@@ -489,7 +492,7 @@ void DkSettings::setToDefaultSettings() {
 	global_p.skipImgs = 10;
 	global_p.numFiles = 10;
 	global_p.loop = false;
-	global_p.scanSubFolders = true;
+	global_p.scanSubFolders = false;
 	global_p.lastDir = QString();
 	global_p.lastSaveDir = QString();
 	global_p.recentFiles = QStringList();
@@ -514,7 +517,7 @@ void DkSettings::setToDefaultSettings() {
 	global_p.ctrlMod = Qt::ControlModifier;
 #endif
 
-	display_p.keepZoom = true;
+	display_p.keepZoom = zoom_keep_same_size;
 	display_p.invertZoom = false;
 	display_p.highlightColor = QColor(0, 204, 255);
 	display_p.bgColorWidget = QColor(0, 0, 0, 100);
@@ -583,6 +586,7 @@ void DkSettings::setToDefaultSettings() {
 	resources_p.cacheMemory = 0;
 	resources_p.fastThumbnailPreview = false;
 	resources_p.filterRawImages = true;
+	resources_p.loadRawThumb = raw_thumb_always;
 	resources_p.filterDuplicats = false;
 	resources_p.preferredExtension = "*.jpg";
 
@@ -1002,7 +1006,7 @@ void DkDisplaySettingsWidget::init() {
 	cbRating->setChecked(DkSettings::slideShow.display.testBit(display_file_rating));
 
 	cbInvertZoom->setChecked(DkSettings::display.invertZoom);
-	cbKeepZoom->setChecked(DkSettings::display.keepZoom);
+	keepZoomButtons[DkSettings::display.keepZoom]->setChecked(true);
 	maximalThumbSizeWidget->setSpinBoxValue(DkSettings::display.thumbSize);
 	cbSaveThumb->setChecked(DkSettings::display.saveThumb);
 	interpolateWidget->setSpinBoxValue(DkSettings::display.interpolateZoomLevel);
@@ -1013,19 +1017,49 @@ void DkDisplaySettingsWidget::init() {
 
 void DkDisplaySettingsWidget::createLayout() {
 	QHBoxLayout* widgetLayout = new QHBoxLayout(this);
-	QVBoxLayout* leftLayout = new QVBoxLayout;
-	QVBoxLayout* rightLayout = new QVBoxLayout;
+	QVBoxLayout* leftLayout = new QVBoxLayout(this);
+	QVBoxLayout* rightLayout = new QVBoxLayout(this);
 
 	QGroupBox* gbZoom = new QGroupBox(tr("Zoom"));
+	gbZoom->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 	QVBoxLayout* gbZoomLayout = new QVBoxLayout(gbZoom);
 	interpolateWidget = new DkSpinBoxWidget(tr("Stop interpolating at:"), tr("% zoom level"), 0, 7000, this, 10);
 	QWidget* zoomCheckBoxes = new QWidget(this);
+	zoomCheckBoxes->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 	QVBoxLayout* vbCheckBoxLayout = new QVBoxLayout(zoomCheckBoxes);
 	vbCheckBoxLayout->setContentsMargins(11,0,11,0);
 	cbInvertZoom = new QCheckBox(tr("Invert Zoom"), this);
-	cbKeepZoom = new QCheckBox(tr("Keep Zoom"), this);
+
+
+	QGroupBox* gbRawLoader = new QGroupBox(tr("Keep Zoom Settings"));
+
+	keepZoomButtonGroup = new QButtonGroup(this);
+
+	keepZoomButtons.resize(DkSettings::raw_thumb_end);
+	keepZoomButtons[DkSettings::zoom_always_keep] = new QRadioButton(tr("Always keep zoom"), this);
+	keepZoomButtons[DkSettings::zoom_keep_same_size] = new QRadioButton(tr("Keep zoom if equal size"), this);
+	keepZoomButtons[DkSettings::zoom_keep_same_size]->setToolTip(tr("If checked, the zoom level is only kept, if the image loaded has the same level as the previous."));
+	keepZoomButtons[DkSettings::zoom_never_keep] = new QRadioButton(tr("Never keep zoom"), this);
+
+	QWidget* keepZoomWidget = new QWidget();
+	keepZoomWidget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+	QVBoxLayout* keepZoomButtonLayout = new QVBoxLayout(keepZoomWidget);
+
+	for (int idx = 0; idx < keepZoomButtons.size(); idx++) {
+		keepZoomButtonGroup->addButton(keepZoomButtons[idx]);
+		keepZoomButtonLayout->addWidget(keepZoomButtons[idx]);
+	}
+
+	//QGridLayout* rawLoaderLayout = new QGridLayout(gbRawLoader);
+	//cbFilterRawImages = new QCheckBox(tr("filter raw images"));
+
+	//rawLoaderLayout->addWidget(rawThumbWidget);
+	//rawLoaderLayout->addWidget(dupWidget);
+	//rawLoaderLayout->addWidget(cbFilterRawImages);
+
+	
 	vbCheckBoxLayout->addWidget(cbInvertZoom);
-	vbCheckBoxLayout->addWidget(cbKeepZoom);
+	vbCheckBoxLayout->addWidget(keepZoomWidget);
 	gbZoomLayout->addWidget(interpolateWidget);
 	gbZoomLayout->addWidget(zoomCheckBoxes);
 
@@ -1068,13 +1102,20 @@ void DkDisplaySettingsWidget::createLayout() {
 
 	widgetLayout->addLayout(leftLayout, 1);
 	widgetLayout->addLayout(rightLayout, 1);
+	adjustSize();
 }
 
 void DkDisplaySettingsWidget::writeSettings() {
 
 	DkSettings::display.invertZoom = (cbInvertZoom->isChecked()) ? true : false;
-	DkSettings::display.keepZoom = (cbKeepZoom->isChecked()) ? true : false;
-	
+
+	for (int idx = 0; idx < keepZoomButtons.size(); idx++) {
+		if (keepZoomButtons[idx]->isChecked()) {
+			DkSettings::display.keepZoom = idx;
+			break;
+		}
+	}
+
 	DkSettings::slideShow.silentFullscreen = cbSilentFullscreen->isChecked();
 
 	DkSettings::slideShow.display.setBit(display_file_name, cbName->isChecked());
@@ -1383,10 +1424,10 @@ void DkMetaDataSettingsWidget::createLayout() {
 	//QLabel* topLabel = new QLabel;
 	QStringList sDescription;
 	for (int i = 0; i  < scamDataDesc.size(); i++) 
-		sDescription << qApp->translate("nmc::DkMetaData", scamDataDesc.at(i).toAscii());
+		sDescription << qApp->translate("nmc::DkMetaData", scamDataDesc.at(i).toLatin1());
 	
 	for (int i = 0; i  < sdescriptionDesc.size(); i++) 
-		sDescription << qApp->translate("nmc::DkMetaData", sdescriptionDesc.at(i).toAscii());
+		sDescription << qApp->translate("nmc::DkMetaData", sdescriptionDesc.at(i).toLatin1());
 	
 
 	//QStringList sDescription = qApp->translate("nmc::DkMetaData",scamDataDesc.toAscii()).split(";") + qApp->translate("nmc::DkMetaData",sdescriptionDesc.toAscii()).split(";");
@@ -1467,6 +1508,8 @@ void DkResourceSettingsWidgets::init() {
 	cbFastThumbnailPreview->setChecked(DkSettings::resources.fastThumbnailPreview);
 	cbFilterRawImages->setChecked(DkSettings::resources.filterRawImages);
 	cbRemoveDuplicates->setChecked(DkSettings::resources.filterDuplicats);
+	
+	rawThumbButtons[DkSettings::resources.loadRawThumb]->setChecked(true);
 }
 
 void DkResourceSettingsWidgets::createLayout() {
@@ -1527,6 +1570,23 @@ void DkResourceSettingsWidgets::createLayout() {
 
 	QGroupBox* gbRawLoader = new QGroupBox(tr("Raw Loader Settings"));
 	
+	rawThumbButtonGroup = new QButtonGroup(this);
+
+	rawThumbButtons.resize(DkSettings::raw_thumb_end);
+
+	rawThumbButtons[DkSettings::raw_thumb_always] = new QRadioButton(tr("Always load JPG if embedded"), this);
+	rawThumbButtons[DkSettings::raw_thumb_if_large] = new QRadioButton(tr("Load JPG if it fits the screen resolution"), this);
+	rawThumbButtons[DkSettings::raw_thumb_never] = new QRadioButton(tr("Never load embedded JPG"), this);
+
+	QWidget* rawThumbWidget = new QWidget();
+	QVBoxLayout* rawThumbButtonLayout = new QVBoxLayout(rawThumbWidget);
+
+	for (int idx = 0; idx < rawThumbButtons.size(); idx++) {
+		rawThumbButtonGroup->addButton(rawThumbButtons[idx]);
+		rawThumbButtonLayout->addWidget(rawThumbButtons[idx]);
+	}
+
+
 	QWidget* dupWidget = new QWidget();
 	QHBoxLayout* hLayout = new QHBoxLayout(dupWidget);
 	hLayout->setContentsMargins(0,0,0,0);
@@ -1550,10 +1610,12 @@ void DkResourceSettingsWidgets::createLayout() {
 	hLayout->addWidget(cmExtensions);
 	hLayout->addStretch();
 
-	QGridLayout* rawLoaderLayuot = new QGridLayout(gbRawLoader);
+	QGridLayout* rawLoaderLayout = new QGridLayout(gbRawLoader);
 	cbFilterRawImages = new QCheckBox(tr("filter raw images"));
-	rawLoaderLayuot->addWidget(dupWidget);
-	rawLoaderLayuot->addWidget(cbFilterRawImages);
+	
+	rawLoaderLayout->addWidget(rawThumbWidget);
+	rawLoaderLayout->addWidget(dupWidget);
+	rawLoaderLayout->addWidget(cbFilterRawImages);
 
 	widgetVBoxLayout->addWidget(gbCache);
 	widgetVBoxLayout->addWidget(gbFastPreview);
@@ -1568,6 +1630,13 @@ void DkResourceSettingsWidgets::writeSettings() {
 	DkSettings::resources.filterRawImages = cbFilterRawImages->isChecked();
 	DkSettings::resources.filterDuplicats = cbRemoveDuplicates->isChecked();
 	DkSettings::resources.preferredExtension = DkImageLoader::fileFilters.at(cmExtensions->currentIndex());
+	
+	for (int idx = 0; idx < rawThumbButtons.size(); idx++) {
+		if (rawThumbButtons[idx]->isChecked()) {
+			DkSettings::resources.loadRawThumb = idx;
+			break;
+		}
+	}
 }
 
 void DkResourceSettingsWidgets::memorySliderChanged(int newValue) {
