@@ -126,7 +126,7 @@ QImage DkThumbNail::computeIntern(QFileInfo file, bool forceLoad, bool forceSave
 		if (thumb.isNull()) {
 			DkBasicLoader loader;
 			
-			if (loader.loadGeneral(file, true))
+			if (loader.loadGeneral(file, true, true))
 				thumb = loader.image();
 		}
 
@@ -373,8 +373,14 @@ void DkThumbPool::getUpdates(QObject* obj, bool isActive) {
 		}
 	}
 
-	if (!registered && isActive)
+	if (!registered && isActive) {
+		
+		// we need an update here if the listener list was empty
+		if (listenerList.isEmpty())
+			updateDir(currentFile);
+
 		listenerList.append(obj);
+	}
 
 }
 
