@@ -32,7 +32,7 @@
 namespace nmc {
 
 // DkControlWidget --------------------------------------------------------------------
-DkControlWidget::DkControlWidget(DkViewPort *parent, Qt::WFlags flags) : QWidget(parent, flags) {
+DkControlWidget::DkControlWidget(DkViewPort *parent, Qt::WindowFlags flags) : QWidget(parent, flags) {
 
 	viewport = parent;
 
@@ -680,7 +680,7 @@ void DkControlWidget::keyReleaseEvent(QKeyEvent *event) {
 
 
 // DkViewPort --------------------------------------------------------------------
-DkViewPort::DkViewPort(QWidget *parent, Qt::WFlags flags) : DkBaseViewPort(parent) {
+DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(parent) {
 
 	testLoaded = false;
 	thumbLoaded = false;
@@ -845,8 +845,10 @@ void DkViewPort::setImage(QImage newImg) {
 	emit enableNoImageSignal(!newImg.isNull());
 
 	//qDebug() << "new image (viewport) loaded,  size: " << newImg.size() << "channel: " << imgQt.format();
+	qDebug() << "keep zoom is always: " << (DkSettings::display.keepZoom == DkSettings::zoom_always_keep);
 
-	if (!DkSettings::display.keepZoom || oldImgRect.isEmpty())
+	if (DkSettings::display.keepZoom == DkSettings::zoom_never_keep || oldImgRect.isEmpty() || 
+		(DkSettings::display.keepZoom == DkSettings::zoom_keep_same_size && oldImgRect != imgRect))
 		worldMatrix.reset();
 	else {
 		imgViewRect = oldImgViewRect;
@@ -1215,6 +1217,8 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 
 	painter.end();
 
+	//qDebug() << "painting main widget...";
+
 	// propagate
 	QGraphicsView::paintEvent(event);
 
@@ -1441,9 +1445,11 @@ void DkViewPort::wheelEvent(QWheelEvent *event) {
 
 }
 
+#if QT_VERSION < 0x050000
 #ifndef QT_NO_GESTURES
 int DkViewPort::swipeRecognition(QNativeGestureEvent* event) {
 	
+
 	if (posGrab.isNull()) {
 		posGrab = event->position;
 		return no_swipe;
@@ -1502,6 +1508,7 @@ int DkViewPort::swipeRecognition(QNativeGestureEvent* event) {
 
 }
 #endif
+#endif
 
 void DkViewPort::swipeAction(int swipeGesture) {
 
@@ -1638,6 +1645,11 @@ void DkViewPort::settingsChanged() {
 
 void DkViewPort::setEditedImage(QImage newImg) {
 
+	if (newImg.isNull()) {
+		controller->setInfo(tr("Attempted to set NULL image"));	// not sure if users understand that
+		return;
+	}
+
 	QFileInfo file = loader->getFile();
 	unloadImage();
 	setImage(newImg);
@@ -1978,7 +1990,7 @@ void DkViewPort::cropImage(DkRotatingRect rect, const QColor& bgCol) {
 }
 
 // DkViewPortFrameless --------------------------------------------------------------------
-DkViewPortFrameless::DkViewPortFrameless(QWidget *parent, Qt::WFlags flags) : DkViewPort(parent) {
+DkViewPortFrameless::DkViewPortFrameless(QWidget *parent, Qt::WindowFlags flags) : DkViewPort(parent) {
 	
 #ifdef Q_WS_MAC
 	parent->setAttribute(Qt::WA_MacNoShadow);
@@ -2404,7 +2416,7 @@ QTransform DkViewPortFrameless::getScaledImageMatrix() {
 	return imgMatrix;
 }
 
-DkViewPortContrast::DkViewPortContrast(QWidget *parent, Qt::WFlags flags) : DkViewPort(parent) {
+DkViewPortContrast::DkViewPortContrast(QWidget *parent, Qt::WindowFlags flags) : DkViewPort(parent) {
 
 	isColorPickerActive = false;
 	activeChannel = 0;
